## City distances

### Description

Distance in miles between twelve cities in the USA. The dataset is used to illustrate multi-dimensional scaling (MDS).

### Variables

A data frame with 78 observations on 3 variable.

- from = City in which travel starts
- to = City in which travel ends
- distance = Distance in miles as-the-crow-flies